#Dishant Sethi

#Topsis Package assignment 

##how to install this package 

#pip install Topsis-Dishant-101917006

##USAGE GUIDE

#import topsis
#topsis.topsis("input_file.csv", "1,1,1,1", "+,-,+,-") 


#Dishant Sethi 2022